@@ -5,12 +5,11 @@
 
 namespace BT
 {
+
 class DecoratorSubtreeNode : public DecoratorNode
 {
   public:
-    DecoratorSubtreeNode(const std::string& name) : DecoratorNode(name, NodeParameters())
-    {
-    }
+    DecoratorSubtreeNode(const std::string& name);
 
     virtual ~DecoratorSubtreeNode() override = default;
 
@@ -21,7 +20,6 @@ class DecoratorSubtreeNode : public DecoratorNode
     {
         return NodeType::SUBTREE;
     }
-
 };
 
 
